% Updated: July 2011
function g = construct_grid_crra(grid, data) 
%% functions that it calls
% cutoffs_crra_health -> crra_diff -> crra
% std_diff -> crra
% ltd_diff -> crra

% want to use CRRA for all domains
% use average wage where needed to compute cutoffs
% need to change RX, Dental and Health insurance. -- TO DO 

'Running CRRA'
%% scalars
delta = .95;			% LTD discount rate

%% 401k scalars
% see file calibration.do for these numbers
r_m = .0103426;     % market return
s_m = .028517;      % (market-risk free) standard deviation
r_f = .0035559;     % risk free
riskpr = (r_m-r_f)/s_m^2;    % risk premium

% average share invested in the risk free if interior
avg_rfree = mean(data.fin.rfree(data.fin.rfree~=1 & data.fin.rfree~=0));    
% average share in risky
alpha = 1-avg_rfree;


%% Health Insurance
% need one set of cutoffs for every set of prices, coverage tier, wage group combination
[dcrra.hi.opts, I, grid.hi.menu] = unique([data.hi.price, data.hi.covgtier, data.wage_avg], 'rows');
dcrra.hi.nmenus = size(dcrra.hi.opts, 1);		

'hi'
for k_hi = 1:size(grid.l_hi, 2)
    for m = 1:dcrra.hi.nmenus
        [k_hi, m];
        dcrra.hi.oop = data.hi.oop(find(data.hi.covgtier == dcrra.hi.opts(m, end-1)),:);
        grid.hi.cutoffs{k_hi}(m,:)=cutoffs_crra_health(grid.l_hi(k_hi), dcrra.hi.oop, dcrra.hi.opts(m,:));
    end
end

%% Drug Insurance
[dcrra.rx.opts, I, grid.rx.menu] = unique([data.rx.price, data.rx.covgtier, data.wage_avg], 'rows');
dcrra.rx.nmenus = size(dcrra.rx.opts, 1);		

'rx'
for k_rx = 1:size(grid.l_rx, 2)
    for m = 1:dcrra.rx.nmenus
        [k_rx, m];
        dcrra.rx.oop = data.rx.oop(find(data.rx.covgtier == dcrra.rx.opts(m, end-1)),:);
        grid.rx.cutoffs{k_rx}(m,:)=cutoffs_crra_health(grid.l_rx(k_rx), dcrra.rx.oop, dcrra.rx.opts(m,:));
    end
end

%% Dental Insurance
[dcrra.dental.opts, I, grid.dental.menu] = unique([data.dental.price, data.dental.covgtier, data.wage_avg], 'rows');
dcrra.dental.nmenus = size(dcrra.dental.opts, 1);		

'dental'
for k_dental = 1:size(grid.l_dental, 2)
    for m = 1:dcrra.dental.nmenus
        [k_dental, m];
        dcrra.dental.oop = data.dental.oop(find(data.dental.covgtier == dcrra.dental.opts(m, end-1)),:);
        grid.dental.cutoffs{k_dental}(m,:)=cutoffs_crra_health(grid.l_dental(k_dental), dcrra.dental.oop, dcrra.dental.opts(m,:));
    end
end

%% LTD CRRA - options are defined by the replacement rates
[dcrra.ltd.opts, I, grid.ltd.menu] = unique(data.ltd.opts, 'rows');		% we don't use I anywhere
dcrra.ltd.nmenus = size(dcrra.ltd.opts,1);		% number of options

'ltd'
for k_ltd = 1:size(grid.l_ltd,2) % ltdi
    for m=1:dcrra.ltd.nmenus
        grid.ltd.cutoffs{k_ltd}(m,:) = cutoffs_crra_ltd(delta, grid.l_ltd(k_ltd), data.ltd.shock, dcrra.ltd.opts(m,:));
    end
end
grid.ltd.cutoffs{1}

%% STD
[dcrra.std.opts, I, grid.std.menu] = unique(data.std.opts, 'rows');
dcrra.std.nmenus = size(dcrra.std.opts, 1);		% number of menus

'std'
for k_std = 1:size(grid.l_std,2) % stdi 
    for m=1:dcrra.std.nmenus
        grid.std.cutoffs{k_std}(m,:) = cutoffs_crra_std(grid.l_std(k_std), data.std.shock, dcrra.std.opts(m,:));
    end
end
grid.std.cutoffs{1}

%% 401k - discrete
grid.fin.menu = (data.fin.rfree >= 0);		% only one menu
'Financial menu'
tabulate(grid.fin.menu)
size(grid.fin.menu)
for k_fin = 1:size(grid.l_fin, 2)
	ub1 = 2*grid.l_fin(k_fin)*riskpr/(1+alpha);
	ub2 = 2*grid.l_fin(k_fin)*riskpr/alpha;
	grid.fin_disc.cutoffs(k_fin,:) = max([0,ub1, ub2, inf],0);
end

%% 401k - continuous
eps = 10^(-6);
share(:,2) = 1-data.fin.rfree;
share(:,1) = 1-data.fin.rfree + eps;
share((share(:,2)==1),1) = inf;					% for 100% in risky they could be at a corner
grid.fin.cutoffs = riskpr*1./share;             % multiply by k_fin in the overlap_all file

grid;
save(grid.name, 'grid')

end
