function g = construct_grid_cara(grid, data, income)
%% scalars
delta = .95;

%% 401k - constants
% see file calibration.do for these numbers
r_m = .0103426;
s_m = .028517;
r_f = .0035559;
riskpr = (r_m-r_f)/s_m^2;
% riskpr = 1
avg_rfree = mean(data.fin.rfree(data.fin.rfree~=1 & data.fin.rfree~=0));
alpha = 1-avg_rfree;

%% LTD CRRA - options are defined by the replacement rates
[dcrra.ltd.opts, I, grid.ltd.menu] = unique(data.ltd.opts, 'rows');		% we don't use I anywhere
dcrra.ltd.nmenus = size(dcrra.ltd.opts,1);		% number of options

'ltd'
for k_ltd = 1:size(grid.l_ltd,2) % ltdi
    for m=1:dcrra.ltd.nmenus
        grid.ltd.cutoffs{k_ltd}(m,:) = cutoffs_crra_ltd(delta, grid.l_ltd(k_ltd), data.ltd.shock, dcrra.ltd.opts(m,:));
    end
end
grid.ltd.cutoffs{1}

%% STD
[dcrra.std.opts, I, grid.std.menu] = unique(data.std.opts, 'rows');
dcrra.std.nmenus = size(dcrra.std.opts, 1);		% number of menus

'std'
for k_std = 1:size(grid.l_std,2) % stdi 
    for m=1:dcrra.std.nmenus
        grid.std.cutoffs{k_std}(m,:) = cutoffs_crra_std(grid.l_std(k_std), data.std.shock, dcrra.std.opts(m,:));
    end
end
grid.std.cutoffs{1}

%% 401k - discrete
for k_fin = 1:size(grid.l_fin, 2)
	ub1 = 2*grid.l_fin(k_fin)*riskpr/(1+alpha);
	ub2 = 2*grid.l_fin(k_fin)*riskpr/alpha;
	grid.fin_disc.cutoffs(k_fin,:) = max([0,ub1, ub2, inf],0);
end

%% 401k - continuous
eps = 10^(-6);
share(:,2) = 1-data.fin.rfree;
share(:,1) = 1-data.fin.rfree + eps;
share((share(:,2)==1),1) = inf;					% for 100% in risky they could be at a corner
grid.fin.cutoffs = riskpr*1./share;             % multiply by k_fin in the overlap_all file

%% HI
% defined by prices and coverage tier. wages will cancel out
[dcara.hi.opts, I, grid.hi.menu] = unique([data.hi.price, data.hi.covgtier], 'rows');
dcara.hi.nmenus = size(dcara.hi.opts, 1);		

for m = 1:dcara.hi.nmenus 
    % unique set of prices for each coverage tier
    dcara.hi.price(m,:) = dcara.hi.opts(m,1:5);
    % menu defined as coverage tier, price vector
    dcara.hi.oop{m} = data.hi.oop(find(data.hi.covgtier == dcara.hi.opts(m,end)),:);
end

% Compute cutoffs
'hi'
for k_hi = 1:size(grid.l_hi,2)
    k_hi
    % for each value of lambda, compute a matrix of cutoffs of size - groups by 6
    % group is each set of individuals for whom we need to compute a different set of cutoffs
    % this is defined by coverage tier and prices (or menu)
    grid.hi.cutoffs{k_hi} = cutoffs(grid.l_hi(k_hi), dcara.hi);
end

%% RX
[dcara.rx.opts, I, grid.rx.menu] = unique([data.rx.price, data.rx.covgtier], 'rows');
dcara.rx.nmenus = size(dcara.rx.opts, 1);		

for m = 1:dcara.rx.nmenus
    dcara.rx.price(m,:) = dcara.rx.opts(m,1:3);
    dcara.rx.oop{m} = data.rx.oop(find(data.rx.covgtier == dcara.rx.opts(m,end)),:);
end

'rx'
for k_rx = 1:size(grid.l_rx,2)
    k_rx
    grid.rx.cutoffs{k_rx} = cutoffs(grid.l_rx(k_rx), dcara.rx);
end

%% DENTAL
[dcara.dental.opts, I, grid.dental.menu] = unique([data.dental.price, data.dental.covgtier], 'rows');
dcara.dental.nmenus = size(dcara.dental.opts, 1);		

for m = 1:dcara.dental.nmenus
    dcara.dental.price(m,:) = dcara.dental.opts(m,1:2);
    dcara.dental.oop{m} = data.dental.oop(find(data.dental.covgtier == dcara.dental.opts(m,end)),:);
end

'dental'
for k_d = 1:size(grid.l_dental,2)
    k_d
    grid.dental.cutoffs{k_d} = cutoffs(grid.l_dental(k_d), dcara.dental);
end

grid
save(grid.name, 'grid')
end
