set more off
capture log close
clear
clear matrix
set mem 1g

local c_date = c(current_date)
local c_date = subinstr("`c_date'", " ", "_", .)
log using ../log/table3b_b_`c_date', text replace

use ../dta/sample_080911.dta, replace

* TABLE 3B - PANEL B Controlling for risk in baseline model - realized and predicted risk all domains + menuFE + RISK SCORE
mkspline age_spline = age, cubic nknots(7)
mkspline wage_spline = wage_amt_hr, cubic nknots(7)
mkspline tenure_spline = tenure_hr, cubic nknots(4)
gen age_female = age*female
gen age_single = age*single
gen age_hourly = age*hourly
gen over65 = (age>65)

foreach var in total rx_total dental_total std_days ltd_days {
	qui xi: reg `var' *spline* female hourly  white union single family_size age_single age_female age_hourly over65 i.state_loc
	predict `var'_xb, xb
}

qui: xi: sureg (hi_ord drug_ord dental_ord stdi_ord ltd_ord rfree_cont = rs_fam total rx_total dental_total std_days ltd_days total_xb rx_total_xb dental_total_xb std_days_xb ltd_days_xb i.allmenu), notable corr
local nobs=e(N)
matrix CR = corr(e(Sigma))
corr_matrix CR `nobs'
matrix colnames final = "HI" "Drug" "Dental" "STDI" "LTDI"
matrix rownames final = "Drug" "p" "Dental" "p" "STDI" "p" "LTDI" "p" "401k" "p" "N" "Avg" 
matrix list final, format(%9.3f)

* bootstrap results to get p-values
capture program drop bootols
prog define bootols, rclass
	preserve
	 bsample
		drop *xb
		foreach var in total rx_total dental_total std_days ltd_days {
			qui xi: reg `var' *spline* female hourly  white union single family_size age_single age_female age_hourly over65 i.state_loc
			predict `var'_xb, xb
		}

		xi: sureg (hi_ord drug_ord dental_ord stdi_ord ltd_ord rfree_cont = rs_fam total rx_total dental_total std_days ltd_days total_xb rx_total_xb dental_total_xb std_days_xb ltd_days_xb i.allmenu), notable corr

		matrix CR = corr(e(Sigma))
		return scalar hi_rx = CR[2,1]
		return scalar hi_dental = CR[3,1]
		return scalar hi_std = CR[4,1]
		return scalar hi_ltd = CR[5,1]
		return scalar hi_401k = CR[6,1]
		return scalar rx_dental = CR[3,2]
		return scalar rx_std = CR[4,2]
		return scalar rx_ltd = CR[5,2]
		return scalar rx_401k = CR[6,2]
		return scalar dental_std = CR[4,3]
		return scalar dental_ltd = CR[5,3]
		return scalar dental_401k = CR[6,3]
		return scalar std_ltd = CR[5,4]
		return scalar std_401k = CR[6,4]
		return scalar ltd_401k = CR[6,5]
	restore
end

simulate hi_rx = r(hi_rx) hi_dental = r(hi_dental) hi_std = r(hi_std) hi_ltd = r(hi_ltd) hi_401k = r(hi_401k) rx_dental = r(rx_dental) rx_std = r(rx_std) rx_ltd = r(rx_ltd) rx_401k = r(rx_401k) dental_std = r(dental_std) dental_ltd = r(dental_ltd) dental_401k = r(dental_401k) std_ltd = r(std_ltd) std_401k = r(std_401k) ltd_401k = r(ltd_401k), reps(25) seed(12345): bootols
foreach v of varlist * {
	gen p_`v' = (`v'<0)
	}

sum p*
